Documentation
¶
Index ¶
- func Create(w http.ResponseWriter, r *http.Request)
- func Delete(w http.ResponseWriter, r *http.Request)
- func FirstUser()
- func Index(w http.ResponseWriter, r *http.Request)
- func Route(w http.ResponseWriter, r *http.Request)
- func Show(w http.ResponseWriter, r *http.Request)
- func Update(w http.ResponseWriter, r *http.Request)
- func UserAuth(w http.ResponseWriter, r *http.Request)
- type APIToken
- type JSONTOKEN
- type Message
- type User
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func FirstUser ¶
func FirstUser()
FirstUser is called from main.go and is used to create an admin user on first run.
func Route ¶
func Route(w http.ResponseWriter, r *http.Request)
Route is used to route methods for individual user actions
Types ¶
type APIToken ¶
type APIToken struct {
APIToken string
}
APIToken is used to generate an API JSON message
Click to show internal directories.
Click to hide internal directories.